# K230 CanMV SPI 模块API手册

![cover](../images/canaan-cover.png)

版权所有©2023北京嘉楠捷思信息技术有限公司

<div style="page-break-after:always"></div>

## 免责声明

您购买的产品、服务或特性等应受北京嘉楠捷思信息技术有限公司（“本公司”，下同）及其关联公司的商业合同和条款的约束，本文档中描述的全部或部分产品、服务或特性可能不在您的购买或使用范围之内。除非合同另有约定，本公司不对本文档的任何陈述、信息、内容的正确性、可靠性、完整性、适销性、符合特定目的和不侵权提供任何明示或默示的声明或保证。除非另有约定，本文档仅作为使用指导参考。

由于产品版本升级或其他原因，本文档内容将可能在未经任何通知的情况下，不定期进行更新或修改。

## 商标声明

![logo](../images/logo.png)、“嘉楠”和其他嘉楠商标均为北京嘉楠捷思信息技术有限公司及其关联公司的商标。本文档可能提及的其他所有商标或注册商标，由各自的所有人拥有。

**版权所有 © 2023北京嘉楠捷思信息技术有限公司。保留一切权利。**
非经本公司书面许可，任何单位和个人不得擅自摘抄、复制本文档内容的部分或全部，并不得以任何形式传播。

<div style="page-break-after:always"></div>

## 目录

[TOC]

## 前言

### 概述

本文档主要介绍machine模块下的SPI类API。

### 读者对象

本文档（本指南）主要适用于以下人员：

- 技术支持工程师
- 软件开发工程师

### 缩略词定义

| 简称 | 说明 |
| ---- | ---- |
| SPI  |  Serial Peripheral Interface |

### 修订记录

| 文档版本号 | 修改说明 | 修改者     | 日期       |
| ---------- | -------- | ---------- | ---------- |
| V1.0       | 初版     | 软件部      | 2023-10-23 |

## 1. 概述

K230内部包含三个SPI硬件模块，片选的极性可配置；支持时钟速率可配。
通道输出IO配置参考IOMUX模块。

## 2. API描述

SPI类位于machine模块下

### 示例

```python
from machine import SPI
# spi init clock 5MHz, polarity 0, phase 0, data bitwide 8bits
spi = SPI(id, baudrate=5000000, polarity=0, phase=0, bits=8)
# Sending data to the slave
spi.write(buf)
# Sending data while reading data to variables
spi.write_readinto(write_buf, read_buf)
# close spi
spi.deinit()
```

### 构造函数

```python
spi = machine.SPI(id, baudrate=20, polarity=0, phase=0, bits=8)
```

【参数】

- id： SPI ID, [0~2] (spi.SPI0~spi.SPI2)
- baudrate: SPI时钟baudrate，Fsclk_out=Fssi_clk/BAUDR
- polarity: 极性
- phase: 相位
- bits: 数据位宽

### write

```python
spi.write(buf)
```

发送数据

【参数】

- buf： bytearray 类型， 定义了数据及长度

【返回值】

无

### write_readinto

```python
spi.write_readinto(write_buf, read_buf)
```

发送数据，同时读取数据到变量

【参数】

- write_buf： bytearray 类型， 定义了需要发送的数据及长度
- read_buf： bytearray 类型， 定义了接收数据存放的位置

【返回值】

无

### deinit

```python
spi.deinit()
```

注销spi

【参数】

无

【返回值】

无
